@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "3.10.0"
+version     = "3.10.1"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/opt/gnome"
+prefix      = "/home/jd/checkout/orca/bld"
 
 # The package name (should be "orca").
 #
